@@ -20,9 +20,21 @@ def last_discovery_path() -> str:
     return "/discoveries/last"
 
 
-def asset_search_path() -> str:
+def device_search_path() -> str:
     return "/assets/assets"
 
 
-def asset_detail_path(hostname: str) -> str:
+def device_detail_path(hostname: str) -> str:
     return f"/assets/assets/{hostname}"
+
+
+def queries_path() -> str:
+    return "/queries/queries"
+
+
+def query_detail_path(query_id: int) -> str:
+    return f"/queries/queries/{query_id}"
+
+
+def ping_pong_path() -> str:
+    return "/api/ping"
